@@ -1,8 +1,7 @@
 import os
 import re
 
-_get_module_path = lambda path: os.path.normpath(os.path.join(os.getcwd(),
-                                                 os.path.dirname(__file__), path))
+
 
 """
 direct_transform = {
@@ -132,6 +131,18 @@ def max_backward_match(word_list, vocab, max_k=5):
     return res
 
 
+def max_backward_match_end(word_list, vocab, max_k=3):
+    res = [word_list]
+    end = len(word_list)
+    for i in range(max_k):
+        start = end - max_k + i
+        start = start if start >= 0 else 0
+        temp = "".join(word_list[start:end])
+        if temp in vocab:
+            res.append(word_list[:start])
+    return res
+
+
 def cut_text_index(word_list):
     index_dict = dict()
     ind = 0
@@ -142,7 +153,7 @@ def cut_text_index(word_list):
     return index_dict
 
 
-def _read_table(filename=_get_module_path("unit_transform")):
+def _read_table(filename):
     res = []
     with open(filename, "r") as f:
         for line in f:
@@ -159,9 +170,10 @@ def _read_table(filename=_get_module_path("unit_transform")):
                 di[line[0]] = [line[1], float(line[2])]
     return di
 
-def _read_list(filename=_get_module_path("organization.txt")):
+def _read_list(filename):
     res = set()
     with open(filename, "r") as f:
         for line in f:
             res.add(line.strip())
-    return res
\ No newline at end of file
+    return res
+
